//+---------------------------------------------------------------------+
//|                                                           XRAVI.mq5 | 
//|                                Copyright  2011,   Nikolay Kositsin | 
//|                                 Khabarovsk,   farria@mail.redcom.ru | 
//+---------------------------------------------------------------------+
//|          SmoothAlgorithms.mqh |
//|   (): MetaTrader\\MQL5\Include                      |
//+---------------------------------------------------------------------+
#property copyright "Copyright  2011, Nikolay Kositsin"
#property link "farria@mail.redcom.ru"
#property description "Range Action Verification Index"
//----   
#property version   "1.00"
//----     
#property indicator_separate_window 
//----   
#property indicator_buffers 1 
//----     
#property indicator_plots   1
//+-----------------------------------+
//|       |
//+-----------------------------------+
//----     
#property indicator_type1   DRAW_LINE
//----        DodgerBlue
#property indicator_color1 DodgerBlue
//----   -  
#property indicator_style1  STYLE_SOLID
//----     1
#property indicator_width1  1
//----   
#property indicator_label1  "XRAVI"
//+----------------------------------------------+
//|     |
//+----------------------------------------------+
#property indicator_level1 +0.1
#property indicator_level2 -0.1
#property indicator_levelcolor Red
#property indicator_levelstyle STYLE_DASHDOTDOT

//+-----------------------------------+
//|    CXMA             |
//+-----------------------------------+
#include <SmoothAlgorithms.mqh> 
//+-----------------------------------+

//----    CXMA   SmoothAlgorithms.mqh
CXMA XMA1,XMA2;
//+-----------------------------------+
//|             |
//+-----------------------------------+
enum Applied_price_ // 
  {
   PRICE_CLOSE_ = 1,     //Close
   PRICE_OPEN_,          //Open
   PRICE_HIGH_,          //High
   PRICE_LOW_,           //Low
   PRICE_MEDIAN_,        //Median Price (HL/2)
   PRICE_TYPICAL_,       //Typical Price (HLC/3)
   PRICE_WEIGHTED_,      //Weighted Close (HLCC/4)
   PRICE_SIMPL_,         //Simple Price (OC/2)
   PRICE_QUARTER_,       //Quarted Price (HLOC/4) 
   PRICE_TRENDFOLLOW0_,  //TrendFollow_1 Price 
   PRICE_TRENDFOLLOW1_   //TrendFollow_2 Price 
  };
/*enum Smooth_Method -     SmoothAlgorithms.mqh
  {
   MODE_SMA_,  // SMA
   MODE_EMA_,  // EMA
   MODE_SMMA_, // SMMA
   MODE_LWMA_, // LWMA
   MODE_JJMA,  // JJMA
   MODE_JurX,  // JurX
   MODE_ParMA, // ParMA
   MODE_T3,    // T3
   MODE_VIDYA, // VIDYA
   MODE_AMA,   // AMA
  }; */
//+-----------------------------------+
//|         |
//+-----------------------------------+
input Smooth_Method MA_SMethod=MODE_SMA;//  
input int Length1=7;                    //   
input int Length2=65;                   //                      
input int SmPhase=15;                   //  ,
input Applied_price_ IPC=PRICE_CLOSE;   //  
input int Shift=0;                      //      
//+-----------------------------------+

//----   ,    
//----      
double XRAVI[];
//----      
int StartBars;
//+------------------------------------------------------------------+   
//| XRAVI indicator initialization function                          | 
//+------------------------------------------------------------------+ 
void OnInit()
  {
//----     
   int StartBars1=XMA1.GetStartBars(MA_SMethod, Length1, SmPhase);
   int StartBars2=XMA1.GetStartBars(MA_SMethod, Length2, SmPhase);
   StartBars=MathMax(StartBars1,StartBars2);
//----       
   XMA1.XMALengthCheck("Length", Length1);
   XMA1.XMALengthCheck("Length", Length2);
   XMA1.XMAPhaseCheck("Phase", SmPhase, MA_SMethod);

//----    XRAVI[]   
   SetIndexBuffer(0,XRAVI,INDICATOR_DATA);
//----    1  
   PlotIndexSetInteger(0,PLOT_SHIFT,Shift);
//----      
   PlotIndexSetInteger(0,PLOT_DRAW_BEGIN,StartBars);
//----      DataWindow
   PlotIndexSetString(0,PLOT_LABEL,"XRAVI");
//----   ,      
   PlotIndexSetDouble(0,PLOT_EMPTY_VALUE,0);

//----      
   string shortname;
   string Smooth1=XMA1.GetString_MA_Method(MA_SMethod);
   StringConcatenate(shortname,"XRAVI(",Length1,", ",Length2,", ",Smooth1,")");
//----           
   IndicatorSetString(INDICATOR_SHORTNAME,shortname);

//----     
   IndicatorSetInteger(INDICATOR_DIGITS,2);
//----  
  }
//+------------------------------------------------------------------+ 
//| XRAVI iteration function                                         | 
//+------------------------------------------------------------------+ 
int OnCalculate(const int rates_total,    //       
                const int prev_calculated,//       
                const datetime &time[],
                const double &open[],
                const double &high[],
                const double &low[],
                const double &close[],
                const long &tick_volume[],
                const long &volume[],
                const int &spread[])
  {
//----       
   if(rates_total<StartBars) return(0);
//----       
   double price_,x1xma,x2xma;
//----        
   int first,bar;
//----    first    
   if(prev_calculated>rates_total || prev_calculated<=0) //      
      first=0;                                           //      
   else first=prev_calculated-1;                         //      
//----    
   for(bar=first; bar<rates_total && !IsStopped(); bar++)
     {
      //----   PriceSeries     price_
      price_=PriceSeries(IPC,bar,open,low,high,close);
      //----    XMASeries.  
      x1xma = XMA1.XMASeries(0, prev_calculated, rates_total, MA_SMethod, SmPhase, Length1, price_, bar, false);
      x2xma = XMA2.XMASeries(0, prev_calculated, rates_total, MA_SMethod, SmPhase, Length2, price_, bar, false);
      //----       
      if(x2xma!=0 && x2xma!=EMPTY_VALUE) XRAVI[bar]=100.0*(x1xma-x2xma)/x2xma;
      else                             XRAVI[bar]=EMPTY_VALUE;
     }
//----     
   return(rates_total);
  }
//+------------------------------------------------------------------+
